@@ -1,7 +1,9 @@
 package Log::ger::Plugin::WithCarp;
 
-our $DATE = '2017-08-04'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-07'; # DATE
+our $DIST = 'Log-ger-Plugin-WithWarn'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -10,52 +12,52 @@ use Carp ();
 use Log::ger ();
 
 sub get_hooks {
-    my %conf = @_;
+    my %plugin_conf = @_;
 
     return {
         create_routine_names => [
-            __PACKAGE__, 50,
-            sub {
-                my %args = @_;
+            __PACKAGE__, # key
+            50,          # priority
+            sub {        # hook
+                my %hook_args = @_;
 
                 my $levels = \%Log::ger::Levels;
 
                 return [{
-                    log_subs    => [
+                    logger_subs => [
                         (map { (["log_${_}_carp", $_, "default"], ["log_${_}_cluck", $_, "default"]) }
                              grep {$levels->{$_} == 30} keys %$levels),
                         (map { (["log_${_}_croak", $_, "default"], ["log_${_}_confess", $_, "default"]) }
                              grep {$levels->{$_} > 0 && $levels->{$_} <= 20} keys %$levels),
                     ],
-                    is_subs     => [],
-                    log_methods => [
+                    level_checker_subs => [],
+                    logger_methods => [
                         (map { (["${_}_carp", $_, "default"], ["${_}_cluck", $_, "default"]) }
                              grep {$levels->{$_} == 30} keys %$levels),
                         (map { (["${_}_croak", $_, "default"], ["${_}_confess", $_, "default"]) }
                              grep {$levels->{$_} > 0 && $levels->{$_} <= 20} keys %$levels),
                     ],
-                    logml_methods => [
-                    ],
-                    is_methods  => [
+                    level_checker_methods  => [
                     ],
                 }, 0];
             }],
         before_install_routines => [
-            __PACKAGE__, 50,
-            sub {
-                my %args = @_;
+            __PACKAGE__, # key
+            50,          # priority
+            sub {        # hook
+                my %hook_args = @_;
 
                 # wrap the logger
-                for my $r (@{ $args{routines} }) {
+                for my $r (@{ $hook_args{routines} }) {
                     my ($code, $name, $numlevel, $type) = @$r;
-                    if    ($type eq 'log_sub'    && $name =~ /\Alog_\w+_carp\z/   ) { $r->[0] = sub { $code->(@_);        Carp::carp   ($args{formatters}{default}(@_)."\n") } }
-                    elsif ($type eq 'log_method' && $name =~ /\A\w+_carp\z/       ) { $r->[0] = sub { $code->(@_); shift; Carp::carp   ($args{formatters}{default}(@_)."\n") } }
-                    elsif ($type eq 'log_sub'    && $name =~ /\Alog_\w+_cluck\z/  ) { $r->[0] = sub { $code->(@_);        Carp::cluck  ($args{formatters}{default}(@_)."\n") } }
-                    elsif ($type eq 'log_method' && $name =~ /\A\w+_cluck\z/      ) { $r->[0] = sub { $code->(@_); shift; Carp::cluck  ($args{formatters}{default}(@_)."\n") } }
-                    elsif ($type eq 'log_sub'    && $name =~ /\Alog_\w+_croak\z/  ) { $r->[0] = sub { $code->(@_);        Carp::croak  ($args{formatters}{default}(@_)."\n") } }
-                    elsif ($type eq 'log_method' && $name =~ /\A\w+_croak\z/      ) { $r->[0] = sub { $code->(@_); shift; Carp::croak  ($args{formatters}{default}(@_)."\n") } }
-                    elsif ($type eq 'log_sub'    && $name =~ /\Alog_\w+_confess\z/) { $r->[0] = sub { $code->(@_);        Carp::confess($args{formatters}{default}(@_)."\n") } }
-                    elsif ($type eq 'log_method' && $name =~ /\A\w+_confess\z/    ) { $r->[0] = sub { $code->(@_); shift; Carp::confess($args{formatters}{default}(@_)."\n") } }
+                    if    ($type =~ /^log(ger)?_sub/    && $name =~ /\Alog_\w+_carp\z/   ) { $r->[0] = sub { $code->(@_);        Carp::carp   ($hook_args{formatters}{default}(@_)."\n") } }
+                    elsif ($type =~ /^log(ger)?_method/ && $name =~ /\A\w+_carp\z/       ) { $r->[0] = sub { $code->(@_); shift; Carp::carp   ($hook_args{formatters}{default}(@_)."\n") } }
+                    elsif ($type =~ /^log(ger)?_sub/    && $name =~ /\Alog_\w+_cluck\z/  ) { $r->[0] = sub { $code->(@_);        Carp::cluck  ($hook_args{formatters}{default}(@_)."\n") } }
+                    elsif ($type =~ /^log(ger)?_method/ && $name =~ /\A\w+_cluck\z/      ) { $r->[0] = sub { $code->(@_); shift; Carp::cluck  ($hook_args{formatters}{default}(@_)."\n") } }
+                    elsif ($type =~ /^log(ger)?_sub/    && $name =~ /\Alog_\w+_croak\z/  ) { $r->[0] = sub { $code->(@_);        Carp::croak  ($hook_args{formatters}{default}(@_)."\n") } }
+                    elsif ($type =~ /^log(ger)?_method/ && $name =~ /\A\w+_croak\z/      ) { $r->[0] = sub { $code->(@_); shift; Carp::croak  ($hook_args{formatters}{default}(@_)."\n") } }
+                    elsif ($type =~ /^log(ger)?_sub/    && $name =~ /\Alog_\w+_confess\z/) { $r->[0] = sub { $code->(@_);        Carp::confess($hook_args{formatters}{default}(@_)."\n") } }
+                    elsif ($type =~ /^log(ger)?_method/ && $name =~ /\A\w+_confess\z/    ) { $r->[0] = sub { $code->(@_); shift; Carp::confess($hook_args{formatters}{default}(@_)."\n") } }
                 }
             },
         ],
@@ -77,7 +79,7 @@ Log::ger::Plugin::WithCarp - Add *_{carp,cluck,croak,confess} logging routines
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -113,13 +115,15 @@ L<Log::ger::Plugin::WithWarn>
 
 L<Log::ger::Plugin::WithDie>
 
+L<Log::ger::Plugin::Log4perl>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
