@@ -1,7 +1,9 @@
 package Log::ger::Plugin::WithDie;
 
-our $DATE = '2017-08-04'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-07'; # DATE
+our $DIST = 'Log-ger-Plugin-WithWarn'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -9,7 +11,7 @@ use warnings;
 use Log::ger ();
 
 sub get_hooks {
-    my %conf = @_;
+    my %plugin_conf = @_;
 
     return {
         create_routine_names => [
@@ -20,18 +22,16 @@ sub get_hooks {
                 my $levels = \%Log::ger::Levels;
 
                 return [{
-                    log_subs    => [
+                    logger_subs => [
                         (map { ["log_${_}_die", $_, "default"] }
                              grep {$levels->{$_} > 0 && $levels->{$_} <= 20} keys %$levels),
                     ],
-                    is_subs     => [],
-                    log_methods => [
+                    level_checker_subs => [],
+                    logger_methods => [
                         (map { ["${_}_die", $_, "default"] }
                              grep {$levels->{$_} > 0 && $levels->{$_} <= 20} keys %$levels),
                     ],
-                    logml_methods => [
-                    ],
-                    is_methods  => [
+                    level_checker_methods  => [
                     ],
                 }, 0];
             }],
@@ -43,12 +43,12 @@ sub get_hooks {
                 # wrap the logger
                 for my $r (@{ $args{routines} }) {
                     my ($code, $name, $numlevel, $type) = @$r;
-                    if ($type eq 'log_sub' && $name =~ /\Alog_\w+_die\z/) {
+                    if ($type =~ /^log(ger)?_sub/ && $name =~ /\Alog_\w+_die\z/) {
                         $r->[0] = sub {
                             $code->(@_);
                             die $args{formatters}{default}(@_)."\n";
                         };
-                    } elsif ($type eq 'log_method' && $name =~ /\A\w+_die\z/) {
+                    } elsif ($type =~ /^log(ger)?_method/ && $name =~ /\A\w+_die\z/) {
                         $r->[0] = sub {
                             $code->(@_);
                             shift;
@@ -76,7 +76,7 @@ Log::ger::Plugin::WithDie - Add *_die logging routines
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -104,13 +104,15 @@ L<Log::ger::Plugin::WithWarn>
 
 L<Log::ger::Plugin::WithCarp>
 
+L<Log::ger::Plugin::Log4perl>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
